### R code from vignette source 'Detect.rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: Detect.rnw:80-81
###################################################
options(width=60, continue = "  ") 


###################################################
### code chunk number 2: ummarked-install (eval = FALSE)
###################################################
## ##install package from CRAN mirror
## install.packages(pkgs = "unmarked")


###################################################
### code chunk number 3: ummarked-load (eval = FALSE)
###################################################
## ##load package
## library(unmarked)


###################################################
### code chunk number 4: ummarked-load
###################################################
##load package
library(unmarked)


###################################################
### code chunk number 5: unmarked-import1
###################################################
##import detection data
gfrog <- read.table("Single_season_detection.csv", header = TRUE)
head(gfrog)


###################################################
### code chunk number 6: unmarked-import2
###################################################
##import site covariates
site.covs <- read.table("Single_season_siteCovs.csv", header = TRUE)
head(site.covs)


###################################################
### code chunk number 7: unmarked-import3
###################################################
##import centered air temperature
airtemp <- read.table("Single_season_samplingCovs.csv", header = TRUE)
head(airtemp)


###################################################
### code chunk number 8: unmarked-means
###################################################
##check means
colMeans(site.covs[, c("Perimeter", "Dist.pond")])


###################################################
### code chunk number 9: unmarked-means2
###################################################
##check means
mean(as.vector(as.matrix(airtemp[, -1])))


###################################################
### code chunk number 10: unmarked-center1
###################################################
moy.sites <- colMeans(site.covs[, c("Perimeter", "Dist.pond")])
##center
site.covs$Perim.cent <- site.covs$Perimeter - moy.sites[1]
site.covs$Dist.pond.cent <- site.covs$Dist.pond - moy.sites[2]


###################################################
### code chunk number 11: unmarked-center2
###################################################
air.mean <- mean(as.vector(as.matrix(airtemp[, -1])))
airtemp.cent <- airtemp[, -1] - air.mean


###################################################
### code chunk number 12: unmarked-format
###################################################
gfrog.data <- unmarkedFrameOccu(y = gfrog[, -1], 
                                siteCovs = site.covs,
                                obsCovs = list(Airtemp.cent = 
                                  airtemp.cent))


###################################################
### code chunk number 13: unmarked-formatout (eval = FALSE)
###################################################
## summary(gfrog.data)


###################################################
### code chunk number 14: unmarked-formatout2
###################################################
txt <- capture.output({
summary(gfrog.data)
})
if( length(txt) > 10 ){
  txt <- c( txt[1:15], "..." )
}
cat( txt, sep = "\n" )


###################################################
### code chunk number 15: ummarked-models-null
###################################################
##null
m0 <- occu(~ 1 ~ 1, data = gfrog.data)


###################################################
### code chunk number 16: ummarked-models-outm0
###################################################
summary(m0)


###################################################
### code chunk number 17: unmarked-formatout3 (eval = FALSE)
###################################################
## str(m0)


###################################################
### code chunk number 18: unmarked-formatout4
###################################################
txt <- capture.output({
str(m0)
})
if( length(txt) > 10 ){
  txt <- c( txt[1:10], "..." )
}
cat( txt, sep = "\n" )


###################################################
### code chunk number 19: unmarked-models-m1
###################################################
##psi(.) p(Airtemp.cent)
m1 <- occu(~ Airtemp.cent  ~ 1, data = gfrog.data)


###################################################
### code chunk number 20: unmarked-models-m2
###################################################
##psi(Dist.pond.cent) p(.)
m2 <- occu(~ 1 ~ Dist.pond.cent, data = gfrog.data)


###################################################
### code chunk number 21: unmarked-models-m3
###################################################
##psi(Dist.pond.cent) p(Airtemp.cent)
m3 <- occu(~ Airtemp.cent ~ Dist.pond.cent, data = gfrog.data)


###################################################
### code chunk number 22: ummarked-models-outm1
###################################################
summary(m1)


###################################################
### code chunk number 23: ummarked-models-outm2
###################################################
summary(m2)


###################################################
### code chunk number 24: ummarked-models-outm3
###################################################
summary(m3)


###################################################
### code chunk number 25: unmarked-gof
###################################################
library(AICcmodavg)
#gof <- mb.gof.test(m3, nsim = 10000, plot.hist = TRUE)
#save(gof, file = "gfrog_gof.Rdata")
##load file with goodness of fit results
load("gfrog_gof.Rdata")


###################################################
### code chunk number 26: unmarked-gof (eval = FALSE)
###################################################
## library(AICcmodavg)
## gof <- mb.gof.test(m3, nsim = 10000, plot.hist = TRUE)


###################################################
### code chunk number 27: unmarked-gofout
###################################################
gof$chisq.table
gof$c.hat.est


###################################################
### code chunk number 28: unmarked-gofplot
###################################################
hist(gof$t.star, 
     main = paste("Bootstrapped MacKenzie and Bailey fit statistic (", 
       gof$nsim, " samples)", sep = ""), 
     xlim = range(c(gof$t.star, gof$chi.square)), 
     xlab = paste("Simulated statistic (observed = ", 
            round(gof$chi.square, digits = 2), ")", sep = ""))
title(main = bquote(paste(italic(P), " = ", .(gof$p.value))), 
      line = 0.5)
abline(v = gof$chi.square, lty = "dashed", col = "red")


###################################################
### code chunk number 29: unmarked-aictabsetup
###################################################
##set up models in list
Candidates <- list(m0, m1, m2, m3)

##assign names to the models
Names <- c("m0", "m1", "m2", "m3")


###################################################
### code chunk number 30: unmarked-aictab
###################################################
##model selection
aictab(cand.set = Candidates, modnames = Names, c.hat = 1)


###################################################
### code chunk number 31: unmarked-modavg (eval = FALSE)
###################################################
## modavg(cand.set = Candidates, modnames = Names, 
##        c.hat = 1, parm = "Airtemp.cent", 
##        parm.type = "detect")


###################################################
### code chunk number 32: unmarked-modavg2
###################################################
modavg(cand.set = Candidates, modnames = Names, 
       c.hat = 1, parm = "Airtemp.cent", 
       parm.type = "detect")


###################################################
### code chunk number 33: unmarked-modavgpred
###################################################
range(airtemp.cent)
##create newdata data frame
##centered air temperature
new.dats <- data.frame(Airtemp.cent = 
                       seq(from = min(airtemp.cent),
                           to = max(airtemp.cent), 
                           length.out = 30))
##uncentered air temperature
new.dats$Airtemp <- new.dats$Airtemp.cent + air.mean


###################################################
### code chunk number 34: unmarked-modavgpred
###################################################
preds <- modavgpred(cand.set = Candidates, modnames = Names,
                    c.hat = 1, newdata = new.dats, 
                    type = "response", parm.type = "detect")


###################################################
### code chunk number 35: unmarked-preds (eval = FALSE)
###################################################
## preds


###################################################
### code chunk number 36: unmarked-formatout4
###################################################
txt <- capture.output({
preds
})
if( length(txt) > 10 ){
  txt <- c( txt[1:8], "..." )
}
cat( txt, sep = "\n" )


###################################################
### code chunk number 37: unmarked-modavgpred2
###################################################
new.dats$mod.avg.pred <- preds$mod.avg.pred
new.dats$uncond.se <- preds$uncond.se


###################################################
### code chunk number 38: unmarked-modavgpred3
###################################################
preds.logit <- modavgpred(cand.set = Candidates, 
                          modnames = Names,
                          c.hat = 1, newdata = new.dats, 
                          type = "link", parm.type = "detect")
##add to data set
new.dats$mod.avg.pred.logit <- preds.logit$mod.avg.pred
new.dats$uncond.se.logit <- preds.logit$uncond.se


###################################################
### code chunk number 39: unmarked-modavgpred4
###################################################
##95% CI
new.dats$low95 <- plogis(new.dats$mod.avg.pred.logit - 
                         1.96 * new.dats$uncond.se.logit)
new.dats$upp95 <- plogis(new.dats$mod.avg.pred.logit + 
                         1.96 * new.dats$uncond.se.logit)


###################################################
### code chunk number 40: unmarked-plot2
###################################################
##create plot
plot(new.dats$mod.avg.pred ~ new.dats$Airtemp,
     ylab = "Probabilité de détection",
     xlab = expression(paste("Température de l'air (", 
         degree, "C)")),
     ylim = range(c(new.dats$low95, new.dats$upp95)),
     type = "l")
##add confidence bands
lines(y = new.dats$low95, x = new.dats$Airtemp, 
      lty = "dotted")
lines(y = new.dats$upp95, x = new.dats$Airtemp, 
      lty = "dotted")


###################################################
### code chunk number 41: unmarked-colext-import
###################################################
bfrog <- read.table("OUA_bin.csv", header = TRUE)
head(bfrog)


###################################################
### code chunk number 42: unmarked-colext-import2
###################################################
site.covs <- read.table("Site_covariates_centered.csv",
                        header = TRUE)
head(site.covs)


###################################################
### code chunk number 43: unmarked-colext-import3
###################################################
##airtemp centered and ordered according to site name
airtemp <- read.table("Airtemp_centered.csv",
                        header = TRUE)
##effort centered and ordered according to site name
effort <- read.table("Effort_centered.csv",
                     header = TRUE)
head(airtemp, 3)
head(effort, 3)


###################################################
### code chunk number 44: unmarked-year
###################################################
##set up yearly site covariate
year <- matrix(data = c("2009", "2010"),
               nrow = nrow(site.covs), ncol = 2, byrow = TRUE)
head(year)


###################################################
### code chunk number 45: unmarked-colext-format
###################################################
bfrog.data <- unmarkedMultFrame(y = bfrog[, 3:8], 
                                siteCovs = site.covs[, -c(1,2)],
                                obsCovs = list(Airtemp = 
                                  airtemp, Effort = effort),
                                yearlySiteCovs = 
                                list(Year = year), 
                                numPrimary = 2)


###################################################
### code chunk number 46: unmarked-colext-summary (eval = FALSE)
###################################################
## summary(bfrog.data)


###################################################
### code chunk number 47: unmarked-formatout-colext
###################################################
txt <- capture.output({
summary(bfrog.data)
})
if( length(txt) > 10 ){
  txt <- c( txt[1:17], "..." )
}
cat( txt, sep = "\n" )


###################################################
### code chunk number 48: unmarked-colext-m0
###################################################
m0 <- colext(psiformula = ~ 1,
             gammaformula = ~ 1,
             epsilonformula = ~ 1,
             pformula = ~ Effort + Airtemp, data = bfrog.data)
summary(m0)


###################################################
### code chunk number 49: unmarked-colext-m1
###################################################
m1 <- colext(psiformula = ~ Wetland.area.cent + Reed.presence,
             gammaformula = ~ 1,
             epsilonformula = ~ 1,
             pformula = ~ Effort + Airtemp, data = bfrog.data)
summary(m1)


###################################################
### code chunk number 50: unmarked-colext-m2
###################################################
m2 <- colext(psiformula = ~ Wetland.area.cent + Reed.presence + 
             Wetland.area.cent:Reed.presence,
             gammaformula = ~ 1,
             epsilonformula = ~ 1,
             pformula = ~ Effort + Airtemp, data = bfrog.data)
summary(m2)


###################################################
### code chunk number 51: unmarked-colext-m3
###################################################
m3 <- colext(psiformula = ~ 1,
             gammaformula = ~ 1,
             epsilonformula = ~ Wetland.area.cent + 
             Reed.presence,
             pformula = ~ Effort + Airtemp, data = bfrog.data)
summary(m3)


###################################################
### code chunk number 52: unmarked-colext-m4
###################################################
m4 <- colext(psiformula = ~ 1,
             gammaformula = ~ 1,
             epsilonformula = ~ Wetland.area.cent + 
             Reed.presence + Wetland.area.cent:Reed.presence,
             pformula = ~ Effort + Airtemp, data = bfrog.data)
summary(m4)


###################################################
### code chunk number 53: unmarked-CN
###################################################
extract.CN <- function(mod) {
  hess <- mod@opt$hessian
  eigenvals <- eigen(hess)$values
  CN <- max(eigenvals)/min(eigenvals)
  return(CN)
}


###################################################
### code chunk number 54: unmarked-CNout
###################################################
extract.CN(m0)
extract.CN(m1)
extract.CN(m2)
extract.CN(m3)
extract.CN(m4)


###################################################
### code chunk number 55: unmarked-colext-aic
###################################################
Cand.mods <- list(m0, m1, m2, m3)
Mod.names <- c("nul", "psi(Wetland+Reed)", "psi(Wetland*Reed)", 
               "eps(Wetland+Reed)")


###################################################
### code chunk number 56: unmarked-colext-aic2
###################################################
aictab(cand.set = Cand.mods, modnames = Mod.names)


###################################################
### code chunk number 57: unmarked-colext-evid
###################################################
evidence(aictab(cand.set = Cand.mods, modnames = Mod.names))


###################################################
### code chunk number 58: unmarked-colext-wetland
###################################################
print(modavg(cand.set = Cand.mods, modnames = Mod.names, 
       parm = "Wetland.area.cent", parm.type = "psi", 
       exclude = list("Wetland.area.cent:Reed.presence")), 4)


###################################################
### code chunk number 59: unmarked-colext-wetland
###################################################
modavg(cand.set = Cand.mods, modnames = Mod.names, 
       parm = "Reed.presence", parm.type = "psi", 
       exclude = list("Wetland.area.cent:Reed.presence"))


###################################################
### code chunk number 60: unmarked-colext-wetland
###################################################
modavg(cand.set = Cand.mods, modnames = Mod.names, 
       parm = "Airtemp", parm.type = "detect")


###################################################
### code chunk number 61: unmarked-colext-wetland
###################################################
modavg(cand.set = Cand.mods, modnames = Mod.names, 
       parm = "Effort", parm.type = "detect")


###################################################
### code chunk number 62: unmarked-modavgpred
###################################################
range(effort)
##create newdata data frame
##centered effort
new.dats <- data.frame(Effort = 
                       seq(from = min(effort),
                           to = max(effort), 
                           length.out = 30),
                       Airtemp = 0)
##uncentered effort
new.dats$Effort.orig <- new.dats$Effort + 9.12


###################################################
### code chunk number 63: unmarked-modavgpred
###################################################
preds <- modavgpred(cand.set = Cand.mods, modnames = Mod.names,
                    c.hat = 1, newdata = new.dats, 
                    type = "response", parm.type = "detect")


###################################################
### code chunk number 64: unmarked-modavgpred2
###################################################
new.dats$mod.avg.pred <- preds$mod.avg.pred
new.dats$uncond.se <- preds$uncond.se


###################################################
### code chunk number 65: unmarked-modavgpred3
###################################################
preds.logit <- modavgpred(cand.set = Cand.mods, 
                          modnames = Mod.names,
                          c.hat = 1, newdata = new.dats, 
                          type = "link", parm.type = "detect")
##add to data set
new.dats$mod.avg.pred.logit <- preds.logit$mod.avg.pred
new.dats$uncond.se.logit <- preds.logit$uncond.se


###################################################
### code chunk number 66: unmarked-modavgpred4
###################################################
##95% CI
new.dats$low95 <- plogis(new.dats$mod.avg.pred.logit - 
                         1.96 * new.dats$uncond.se.logit)
new.dats$upp95 <- plogis(new.dats$mod.avg.pred.logit + 
                         1.96 * new.dats$uncond.se.logit)


###################################################
### code chunk number 67: unmarked-plot-colext
###################################################
##create plot
plot(new.dats$mod.avg.pred ~ new.dats$Effort.orig,
     ylab = "Probabilité de détection",
     xlab = "Effort (nombre de stations)",
     ylim = range(c(new.dats$low95, new.dats$upp95)),
     type = "l")
##add confidence bands
lines(y = new.dats$low95, x = new.dats$Effort.orig, 
      lty = "dotted")
lines(y = new.dats$upp95, x = new.dats$Effort.orig, 
      lty = "dotted")


###################################################
### code chunk number 68: unmarked-wetland-modavgpred
###################################################
#range(site.covs$Wetland.area.cent)
##create newdata data frame
##centered effort
new.dats <- data.frame(Wetland.area.cent = 
                       seq(from = min(site.covs$Wetland.area.cent),
                           to = max(site.covs$Wetland.area.cent), 
                           length.out = 30),
                       Reed.presence = 0)
##uncentered effort
new.dats$Wetland.area.orig <- new.dats$Wetland.area.cent + 0.78

##predictions
preds <- modavgpred(cand.set = Cand.mods, modnames = Mod.names,
                    c.hat = 1, newdata = new.dats, 
                    type = "response", parm.type = "psi")

##add to data set
new.dats$mod.avg.pred <- preds$mod.avg.pred
new.dats$uncond.se <- preds$uncond.se

##predictions of logit link scale
preds.logit <- modavgpred(cand.set = Cand.mods, 
                          modnames = Mod.names,
                          c.hat = 1, newdata = new.dats, 
                          type = "link", parm.type = "psi")

##add to data set
new.dats$mod.avg.pred.logit <- preds.logit$mod.avg.pred
new.dats$uncond.se.logit <- preds.logit$uncond.se

##back-transform to original scale
new.dats$low95 <- plogis(new.dats$mod.avg.pred.logit - 
                         1.96 * new.dats$uncond.se.logit)
new.dats$upp95 <- plogis(new.dats$mod.avg.pred.logit + 
                         1.96 * new.dats$uncond.se.logit)

##plot predictions
plot(new.dats$mod.avg.pred ~ new.dats$Wetland.area.orig,
     ylab = "Probabilité d'occupation",
     xlab = "Superficie du milieu humide (ha)",
     ylim = range(c(new.dats$low95, new.dats$upp95)),
     type = "l")
##add confidence bands
lines(y = new.dats$low95, x = new.dats$Wetland.area.orig, 
      lty = "dotted")
lines(y = new.dats$upp95, x = new.dats$Wetland.area.orig, 
      lty = "dotted")


###################################################
### code chunk number 69: unmarked-nmix-siteCovs
###################################################
##import data set
pola <- read.table("pola.txt", header = TRUE)
head(pola, 3)
##import site covariates
pola.site <- read.table("covsite.txt", header = TRUE)
head(pola.site, 3)


###################################################
### code chunk number 70: unmarked-nmix-prec
###################################################
##import prec
pola.prec <- read.table("obscov.prectot.txt", header = TRUE)
head(pola.prec, 3)


###################################################
### code chunk number 71: unmarked-nmix-ht
###################################################
##import ht
pola.ht <- read.table("obscov.ht.txt", header = TRUE)
head(pola.ht, 3)


###################################################
### code chunk number 72: unmarked-nmix-ht
###################################################
##import Jday
pola.jday <- read.table("Jday.txt", header = TRUE)
head(pola.jday, 3)


###################################################
### code chunk number 73: unmarked-nmix-format
###################################################
pola.data <- unmarkedFramePCount(y = pola, siteCovs = pola.site,
                                 obsCovs = list(
                                   Prec = pola.prec, 
                                   Ht = pola.ht, 
                                   Jday = pola.jday))
summary(pola.data)


###################################################
### code chunk number 74: unmarked-nmix-m0-P
###################################################
m0 <- pcount(~ 1 ~ 1, K = 40, mixture = "P", data = pola.data)


###################################################
### code chunk number 75: unmarked-nmix-m0str (eval = FALSE)
###################################################
## str(m0)


###################################################
### code chunk number 76: unmarked-nmix-m0out
###################################################
txt <- capture.output({
str(m0)
})
if( length(txt) > 10 ){
  txt <- c( txt[1:17], "..." )
}
cat( txt, sep = "\n" )


###################################################
### code chunk number 77: unmarked-nmix-m0out
###################################################
summary(m0)


###################################################
### code chunk number 78: unmarked-nmix-P
###################################################
m1 <- pcount(~ Prec + Jday + Ht ~ 1, 
             K = 40, mixture = "P", data = pola.data)
m2 <- pcount(~ Prec + Jday + Ht ~ Snag, 
             K = 40, mixture = "P", data = pola.data)
m3 <- pcount(~ Prec + Jday + Ht ~ Conifer, 
             K = 40, mixture = "P", data = pola.data)
m4 <- pcount(~ Prec + Jday + Ht ~ Snag + Conifer, 
             K = 40, mixture = "P", data = pola.data)
m5 <- pcount(~ Snag + Conifer ~ 1, K = 40, 
             mixture = "P", data = pola.data)
m6 <- pcount(~ Snag + Conifer ~ Snag, K = 40, 
             mixture = "P", data = pola.data)
m7 <- pcount(~ Snag + Conifer ~ Conifer, K = 40,
             mixture = "P", data = pola.data)
m8 <- pcount(~ Snag + Conifer ~ Snag + Conifer, 
             K = 40, mixture = "P", data = pola.data)


###################################################
### code chunk number 79: unmarked-nmix-m1-P
###################################################
summary(m1)


###################################################
### code chunk number 80: unmarked-nmix-m2-P
###################################################
summary(m2)


###################################################
### code chunk number 81: unmarked-nmix-m3-P
###################################################
summary(m3)


###################################################
### code chunk number 82: unmarked-nmix-m4-P
###################################################
summary(m4)


###################################################
### code chunk number 83: unmarked-nmix-m5-P
###################################################
summary(m5)


###################################################
### code chunk number 84: unmarked-nmix-m6-P
###################################################
summary(m6)


###################################################
### code chunk number 85: unmarked-nmix-m7-P
###################################################
summary(m7)


###################################################
### code chunk number 86: unmarked-nmix-m8-P
###################################################
summary(m8)


###################################################
### code chunk number 87: unmarked-nmix-P-CN
###################################################
Cands.pois <- list(m0, m1, m2, m3, m4, m5, m6, m7, m8)
Mod.pois.names <- c("m0", "m1", "m2", "m3", "m4", "m5", 
                    "m6", "m7", "m8")
##add names to list
names(Cands.pois) <- Mod.pois.names
unlist(lapply(Cands.pois, FUN = extract.CN))


###################################################
### code chunk number 88: unmarked-nmix-m8-P
###################################################
aictab(Cands.pois, Mod.pois.names)
coef(m2)


###################################################
### code chunk number 89: unmarked-nmix-m2-P-gof (eval = FALSE)
###################################################
## m2.gof <- Nmix.gof.test(mod = m2, nsim = 5000)


###################################################
### code chunk number 90: unmarked-nmix-m2-P-gof-load
###################################################
#save(m2.gof, file = "Nmix-m2-Pois.Rdata")
#load file with goodness of fit results
load("Nmix-m2-Pois.Rdata")


###################################################
### code chunk number 91: unmarked-gofout
###################################################
m2.gof$chi.square
m2.gof$c.hat.est


###################################################
### code chunk number 92: unmarked-pois-gofplot
###################################################
hist(m2.gof$t.star, 
     main = as.expression(substitute("Bootstrapped "*chi^2*" fit statistic ("*nsim*" samples)",
         list(nsim = m2.gof$nsim))), 
     xlim = range(c(m2.gof$t.star, m2.gof$chi.square)), 
     xlab = paste("Simulated statistic ", 
       "(observed = ", round(m2.gof$chi.square, digits = 2), ")", 
       sep = ""))
title(main = bquote(paste(italic(P), " = ", .(m2.gof$p.value))), 
      line = 0.5)
abline(v = m2.gof$chi.square, lty = "dashed", col = "red")


###################################################
### code chunk number 93: unmarked-nmix-P (eval = FALSE)
###################################################
## m0.nb <- pcount(~ 1 ~ 1, K = 40, mixture = "NB", 
##                 data = pola.data)
## m1.nb <- pcount(~ Prec + Jday + Ht ~ 1, K = 40, 
##                 mixture = "NB", data = pola.data)
## m2.nb <- pcount(~ Prec + Jday + Ht ~ Snag, K = 40, 
##                 mixture = "NB", data = pola.data)
## m3.nb <- pcount(~ Prec + Jday + Ht ~ Conifer, K = 40, 
##                 mixture = "NB", data = pola.data)
## m4.nb <- pcount(~ Prec + Jday + Ht ~ Snag + Conifer, K = 40, 
##                 mixture = "NB", data = pola.data)
## m5.nb <- pcount(~ Snag + Conifer ~ 1, K = 40, 
##                 mixture = "NB", data = pola.data)
## m6.nb <- pcount(~ Snag + Conifer ~ Snag, K = 40, 
##                 mixture = "NB", data = pola.data)
## m7.nb <- pcount(~ Snag + Conifer ~ Conifer, K = 40, 
##                 mixture = "NB", data = pola.data)
## m8.nb <- pcount(~ Snag + Conifer ~ Snag + Conifer, K = 40, 
##                 mixture = "NB", data = pola.data)


###################################################
### code chunk number 94: unmarked-nmix-NB-out
###################################################
summary(m0.nb)


###################################################
### code chunk number 95: unmarked-nmix-NB-out
###################################################
summary(m1.nb)
summary(m2.nb)
summary(m3.nb)
summary(m4.nb)
summary(m5.nb)
summary(m6.nb)
summary(m7.nb)
summary(m8.nb)


###################################################
### code chunk number 96: unmarked-nmix-nb-list
###################################################
Cands.nb <- list(m0.nb, m1.nb, m2.nb, m3.nb, m4.nb, 
                     m5.nb, m6.nb, m7.nb, m8.nb)
Mod.nb.names <- c("m0.nb", "m1.nb", "m2.nb", "m3.nb", 
                  "m4.nb", "m5.nb", "m6.nb", "m7.nb", "m8.nb")
##add names to list
names(Cands.nb) <- Mod.nb.names
unlist(lapply(Cands.nb, extract.CN))


###################################################
### code chunk number 97: unmarked-nmix-m8-P
###################################################
aictab(Cands.nb, Mod.nb.names)
coef(m2.nb)


###################################################
### code chunk number 98: unmarked-nmix-m2-P-gof (eval = FALSE)
###################################################
## m2.nb.gof <- Nmix.gof.test(mod = m2.nb, nsim = 5000)


###################################################
### code chunk number 99: unmarked-nmix-m2-P-gof-load
###################################################
#save(m2.nb.gof, file = "Nmix-m2-NB.Rdata")
#load file with goodness of fit results
load("Nmix-m2-NB.Rdata")


###################################################
### code chunk number 100: unmarked-gofout
###################################################
m2.nb.gof$chi.square
m2.nb.gof$c.hat.est


###################################################
### code chunk number 101: unmarked-nb-gofplot
###################################################
hist(m2.nb.gof$t.star, 
     main = as.expression(substitute("Bootstrapped "*chi^2*" fit statistic ("*nsim*" samples)",
         list(nsim = m2.nb.gof$nsim))), 
     xlim = range(c(m2.nb.gof$t.star, m2.nb.gof$chi.square)), 
     xlab = paste("Simulated statistic ", 
       "(observed = ", round(m2.nb.gof$chi.square, digits = 2), ")", 
       sep = ""))
title(main = bquote(paste(italic(P), " = ", .(m2.nb.gof$p.value))), 
      line = 0.5)
abline(v = m2.nb.gof$chi.square, lty = "dashed", col = "red")


###################################################
### code chunk number 102: unmarked-nb-gof-out
###################################################
##abondances prédites
abond <- predict(m2.nb, type = "state", backTransform = TRUE)
head(abond)
range(abond$Predicted)


###################################################
### code chunk number 103: unmarked-nmix-m8-P
###################################################
aictab(Cands.nb, Mod.nb.names)


###################################################
### code chunk number 104: unmarked-aictab-nb
###################################################
coef(m2.nb)
coef(m4.nb)


###################################################
### code chunk number 105: unmarked-modavg-
###################################################
modavg(cand.set = Cands.nb, modnames = Mod.nb.names,
       parm = "Snag", parm.type = "lambda")


###################################################
### code chunk number 106: unmarked-modavg-
###################################################
modavg(cand.set = Cands.nb, modnames = Mod.nb.names,
       parm = "Conifer", parm.type = "lambda")


###################################################
### code chunk number 107: unmarked-modavg-
###################################################
modavg(cand.set = Cands.nb, modnames = Mod.nb.names,
       parm = "Prec", parm.type = "detect")


###################################################
### code chunk number 108: unmarked-modavg-
###################################################
modavg(cand.set = Cands.nb, modnames = Mod.nb.names,
       parm = "Ht", parm.type = "detect")


###################################################
### code chunk number 109: unmarked-modavg-
###################################################
print(modavg(cand.set = Cands.nb, modnames = Mod.nb.names,
       parm = "Jday", parm.type = "detect"), digits = 4)


###################################################
### code chunk number 110: unmarked-modavgpred-snag
###################################################
range(pola.site$Snag)
##create newdata data frame
##centered effort
new.dats <- data.frame(Conifer = 0,
                       Snag = seq(from = min(pola.site$Snag),
                           to = max(pola.site$Snag), 
                           length.out = 30))
##uncentered Snag
new.dats$Snag.orig <- new.dats$Snag + 3.4


###################################################
### code chunk number 111: unmarked-modavgpred
###################################################
preds <- modavgpred(cand.set = Cands.nb, modnames = Mod.nb.names,
                    c.hat = 1, newdata = new.dats, 
                    type = "response", parm.type = "lambda")


###################################################
### code chunk number 112: unmarked-modavgpred2
###################################################
new.dats$mod.avg.pred <- preds$mod.avg.pred
new.dats$uncond.se <- preds$uncond.se


###################################################
### code chunk number 113: unmarked-modavgpred3
###################################################
preds.log <- modavgpred(cand.set = Cands.nb, 
                        modnames = Mod.nb.names,
                        c.hat = 1, newdata = new.dats, 
                        type = "link", parm.type = "lambda")
##add to data set
new.dats$mod.avg.pred.log <- preds.log$mod.avg.pred
new.dats$uncond.se.log <- preds.log$uncond.se


###################################################
### code chunk number 114: unmarked-modavgpred4
###################################################
##95% CI
new.dats$low95 <- exp(new.dats$mod.avg.pred.log - 
                      1.96 * new.dats$uncond.se.log)
new.dats$upp95 <- exp(new.dats$mod.avg.pred.log + 
                      1.96 * new.dats$uncond.se.log)


###################################################
### code chunk number 115: unmarked-plot-snag
###################################################
##create plot
plot(new.dats$mod.avg.pred ~ new.dats$Snag.orig,
     ylab = "Abondance",
     xlab = "Nombre de chicots",
     ylim = range(c(new.dats$low95, new.dats$upp95)),
     type = "l")
##add confidence bands
lines(y = new.dats$low95, x = new.dats$Snag.orig, 
      lty = "dotted")
lines(y = new.dats$upp95, x = new.dats$Snag.orig, 
      lty = "dotted")


###################################################
### code chunk number 116: unmarked-plot-jday
###################################################
##range(pola.jday)
##create newdata data frame
##centered effort
new.dats <- data.frame(Ht = 0, Prec = 0,
                       Jday = seq(from = min(pola.jday),
                           to = max(pola.jday), 
                           length.out = 30),
                       Conifer = 0, Snag = 0)
##uncentered Snag
new.dats$Jday.orig <- new.dats$Jday + 44.571

preds <- modavgpred(cand.set = Cands.nb, modnames = Mod.nb.names,
                    c.hat = 1, newdata = new.dats, 
                    type = "response", parm.type = "detect")


##add to new.dats
new.dats$mod.avg.pred <- preds$mod.avg.pred
new.dats$uncond.se <- preds$uncond.se

preds.logit <- modavgpred(cand.set = Cands.nb, 
                          modnames = Mod.nb.names,
                          c.hat = 1, newdata = new.dats, 
                          type = "link", parm.type = "detect")
##add to data set
new.dats$mod.avg.pred.logit <- preds.logit$mod.avg.pred
new.dats$uncond.se.logit <- preds.logit$uncond.se

##95% CI
new.dats$low95 <- plogis(new.dats$mod.avg.pred.logit - 
                      1.96 * new.dats$uncond.se.logit)
new.dats$upp95 <- plogis(new.dats$mod.avg.pred.logit + 
                      1.96 * new.dats$uncond.se.logit)

##create plot
plot(new.dats$mod.avg.pred ~ new.dats$Jday.orig,
     ylab = "Probabilité de détection",
     xlab = "Jour julien",
     ylim = range(c(new.dats$low95, new.dats$upp95)),
     type = "l")
##add confidence bands
lines(y = new.dats$low95, x = new.dats$Jday.orig, 
      lty = "dotted")
lines(y = new.dats$upp95, x = new.dats$Jday.orig, 
      lty = "dotted")


###################################################
### code chunk number 117: unmarked-plot-prec
###################################################
##range(pola.prec)
##create newdata data frame
##centered effort
new.dats <- data.frame(Ht = 0, Jday = 0,
                       Prec = seq(from = min(pola.prec),
                           to = max(pola.prec), 
                           length.out = 30),
                       Conifer = 0, Snag = 0)
##uncentered Snag
new.dats$Prec.orig <- new.dats$Prec + 7.95

preds <- modavgpred(cand.set = Cands.nb, modnames = Mod.nb.names,
                    c.hat = 1, newdata = new.dats, 
                    type = "response", parm.type = "detect")


##add to new.dats
new.dats$mod.avg.pred <- preds$mod.avg.pred
new.dats$uncond.se <- preds$uncond.se

preds.logit <- modavgpred(cand.set = Cands.nb, 
                          modnames = Mod.nb.names,
                          c.hat = 1, newdata = new.dats, 
                          type = "link", parm.type = "detect")
##add to data set
new.dats$mod.avg.pred.logit <- preds.logit$mod.avg.pred
new.dats$uncond.se.logit <- preds.logit$uncond.se

##95% CI
new.dats$low95 <- plogis(new.dats$mod.avg.pred.logit - 
                      1.96 * new.dats$uncond.se.logit)
new.dats$upp95 <- plogis(new.dats$mod.avg.pred.logit + 
                      1.96 * new.dats$uncond.se.logit)

##create plot
plot(new.dats$mod.avg.pred ~ new.dats$Prec.orig,
     ylab = "Probabilité de détection",
     xlab = "Quantité de précipitations (mm)",
     ylim = range(c(new.dats$low95, new.dats$upp95)),
     type = "l")
##add confidence bands
lines(y = new.dats$low95, x = new.dats$Prec.orig, 
      lty = "dotted")
lines(y = new.dats$upp95, x = new.dats$Prec.orig, 
      lty = "dotted")


###################################################
### code chunk number 118: unmarked-nmix-P (eval = FALSE)
###################################################
## m0.zip <- pcount(~ 1 ~ 1, K = 40, mixture = "ZIP", 
##                  data = pola.data)
## m1.zip <- pcount(~ Prec + Jday + Ht ~ 1, K = 40, 
##                  mixture = "ZIP", data = pola.data)
## m2.zip <- pcount(~ Prec + Jday + Ht ~ Snag, K = 40, 
##                  mixture = "ZIP", data = pola.data)
## m3.zip <- pcount(~ Prec + Jday + Ht ~ Conifer, K = 40, 
##                  mixture = "ZIP", data = pola.data)
## m4.zip <- pcount(~ Prec + Jday + Ht ~ Snag + Conifer, K = 40, 
##                  mixture = "ZIP", data = pola.data)
## m5.zip <- pcount(~ Snag + Conifer ~ 1, K = 40, mixture = "ZIP", 
##                  data = pola.data)
## m6.zip <- pcount(~ Snag + Conifer ~ Snag, K = 40, 
##                  mixture = "ZIP", data = pola.data)
## m7.zip <- pcount(~ Snag + Conifer ~ Conifer, K = 40, 
##                  mixture = "ZIP", data = pola.data)
## m8.zip <- pcount(~ Snag + Conifer ~ Snag + Conifer, 
##                  K = 40, mixture = "ZIP", data = pola.data)  


###################################################
### code chunk number 119: unmarked-nmix-zip-list (eval = FALSE)
###################################################
## Cands.zip <- list(m0.zip, m1.zip, m2.zip, m3.zip, m4.zip, 
##                      m5.zip, m6.zip, m7.zip, m8.zip)
## Mod.zip.names <- c("m0.zip", "m1.zip", "m2.zip", "m3.zip", 
##                   "m4.zip", "m5.zip", "m6.zip", "m7.zip", 
##                    "m8.zip")
## ##add names to list
## names(Cands.zip) <- Mod.zip.names
## unlist(lapply(Cands.zip, extract.CN))


###################################################
### code chunk number 120: unmarked-nmix-zip-list (eval = FALSE)
###################################################
## aictab(Cands.zip, Mod.zip.names)
## unlist(lapply(list(m2, m2.nb, m2.zip), AICc))


###################################################
### code chunk number 121: unmarked-nmix-m2-zip-gof (eval = FALSE)
###################################################
## m2.zip.gof <- Nmix.gof.test(mod = m2.zip, nsim = 5000)


###################################################
### code chunk number 122: unmarked-nmix-m2-zip-gof-load
###################################################
#save(m2.zip.gof, file = "Nmix-m2-ZIP.Rdata")
#load file with goodness of fit results
load("Nmix-m2-ZIP.Rdata")


###################################################
### code chunk number 123: unmarked-zip-gofplot
###################################################
hist(m2.zip.gof$t.star,
     main = as.expression(substitute("Bootstrapped "*chi^2*" fit statistic ("*nsim*" samples)",
         list(nsim = m2.zip.gof$nsim))), 
     xlim = range(c(m2.zip.gof$t.star, m2.zip.gof$chi.square)), 
     xlab = paste("Simulated statistic ", 
       "(observed = ", round(m2.zip.gof$chi.square, digits = 2), ")", 
       sep = ""))
title(main = bquote(paste(italic(P), " = ", .(m2.zip.gof$p.value))), 
      line = 0.5)
abline(v = m2.zip.gof$chi.square, lty = "dashed", col = "red")


